This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  1a1f6526f308d87a22071539acda3a6da49d9e82 (commit)
       via  65d23e58b813dad360f3315121d3581b4f1123dd (commit)
       via  609ba044308bff8e8c2714c843c7eb84b9d554ac (commit)
       via  477babe0fc83f3cdfc58fc940c061f4d254810b2 (commit)
       via  64eca30dc4d584fb6acf8f6486c016eed50eb7ae (commit)
      from  ed9d665de5d2c949b607e1669ce59a985b9b3f8a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1a1f6526f308d87a22071539acda3a6da49d9e82
commit 1a1f6526f308d87a22071539acda3a6da49d9e82
Merge: ed9d665 65d23e5
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Mon Aug 4 10:07:36 2014 -0400
Commit:     CMake Topic Stage <kwro...@kitware.com>
CommitDate: Mon Aug 4 10:07:36 2014 -0400

    Merge topic 'CMakePackageConfigHelpers-INSTALL_PREFIX' into next
    
    65d23e58 CMakePackageConfigHelpers: Add unit tests for INSTALL_PREFIX option
    609ba044 CMakePackageConfigHelpers: Add INSTALL_PREFIX option
    477babe0 CMakePackageConfigHelpers: restructure documentation and document 
commands
    64eca30d CMakePackageConfigHelpers: Remove unused variable


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=65d23e58b813dad360f3315121d3581b4f1123dd
commit 65d23e58b813dad360f3315121d3581b4f1123dd
Author:     Daniele E. Domenichelli <daniele.domeniche...@iit.it>
AuthorDate: Tue Jul 15 19:51:16 2014 +0200
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Mon Aug 4 10:07:25 2014 -0400

    CMakePackageConfigHelpers: Add unit tests for INSTALL_PREFIX option

diff --git a/Tests/FindPackageTest/CMakeLists.txt 
b/Tests/FindPackageTest/CMakeLists.txt
index 092bf20..f311fb9 100644
--- a/Tests/FindPackageTest/CMakeLists.txt
+++ b/Tests/FindPackageTest/CMakeLists.txt
@@ -374,6 +374,7 @@ endif()
 
 include(CMakePackageConfigHelpers)
 
+# Generate a config file ready to be installed.
 set(INCLUDE_INSTALL_DIR include )
 set(SHARE_INSTALL_DIR "${CMAKE_INSTALL_PREFIX}/share/" )
 set(CURRENT_BUILD_DIR "${CMAKE_CURRENT_BINARY_DIR}" )
@@ -407,6 +408,43 @@ if(Relocatable_FOUND)
   message(SEND_ERROR "Relocatable_FOUND set to TRUE !")
 endif()
 
+# Generate a config file for the build tree.
+set(INCLUDE_INSTALL_DIR include )
+set(SHARE_INSTALL_DIR "${CMAKE_CURRENT_BINARY_DIR}/share/" )
+set(CURRENT_BUILD_DIR "${CMAKE_CURRENT_BINARY_DIR}" )
+
+configure_package_config_file(RelocatableConfig.cmake.in 
"${CMAKE_CURRENT_BINARY_DIR}/RelocatableConfig.cmake"
+                              INSTALL_DESTINATION "${CMAKE_CURRENT_BINARY_DIR}"
+                              PATH_VARS INCLUDE_INSTALL_DIR SHARE_INSTALL_DIR 
CURRENT_BUILD_DIR
+                              INSTALL_PREFIX "${CMAKE_CURRENT_BINARY_DIR}"
+                             )
+
+set(Relocatable_FIND_COMPONENTS AComp BComp CComp)
+set(Relocatable_FIND_REQUIRED_BComp 1)
+include("${CMAKE_CURRENT_BINARY_DIR}/RelocatableConfig.cmake")
+
+if(NOT "${RELOC_INCLUDE_DIR}" STREQUAL "${CMAKE_CURRENT_BINARY_DIR}/include")
+  message(SEND_ERROR "RELOC_INCLUDE_DIR set by configure_package_config_file() 
is set to \"${RELOC_INCLUDE_DIR}\" (expected 
\"${CMAKE_CURRENT_BINARY_DIR}/include\")")
+endif()
+
+if(NOT "${RELOC_SHARE_DIR}" STREQUAL "${CMAKE_CURRENT_BINARY_DIR}/share/")
+  message(SEND_ERROR "RELOC_SHARE_DIR set by configure_package_config_file() 
is set to \"${RELOC_SHARE_DIR}\" (expected 
\"${CMAKE_CURRENT_BINARY_DIR}/share/\")")
+endif()
+
+if(NOT "${RELOC_BUILD_DIR}" STREQUAL "${CMAKE_CURRENT_BINARY_DIR}")
+  message(SEND_ERROR "RELOC_BUILD_DIR set by configure_package_config_file() 
is set to \"${RELOC_BUILD_DIR}\" (expected \"${CMAKE_CURRENT_BINARY_DIR}\")")
+endif()
+
+if(NOT DEFINED Relocatable_FOUND)
+  message(SEND_ERROR "Relocatable_FOUND not defined !")
+endif()
+
+if(Relocatable_FOUND)
+  message(SEND_ERROR "Relocatable_FOUND set to TRUE !")
+endif()
+
+
+
 #-----------------------------------------------------------------------------
 # Test write_basic_config_version_file().
 

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=609ba044308bff8e8c2714c843c7eb84b9d554ac
commit 609ba044308bff8e8c2714c843c7eb84b9d554ac
Author:     Daniele E. Domenichelli <daniele.domeniche...@iit.it>
AuthorDate: Tue Jul 15 19:10:54 2014 +0200
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Mon Aug 4 10:07:17 2014 -0400

    CMakePackageConfigHelpers: Add INSTALL_PREFIX option
    
    This option instructs configure_package_config_file to consider paths
    that are not absolute as relative to the INSTALL_PREFIX directory
    instead of relative to the CMAKE_INSTALL_PREFIX directory.
    
    If this argument is not passed, the default behaviour is to use
    the CMAKE_INSTALL_PREFIX variable.
    
    The new signature is therefore:
    
      configure_package_config_file(<input> <output> INSTALL_DESTINATION <path>
                                                     [PATH_VARS <var1> <var2> 
... <varN>]
                                                     [NO_SET_AND_CHECK_MACRO]
                                                     
[NO_CHECK_REQUIRED_COMPONENTS_MACRO]
                                                     [INSTALL_PREFIX <path>])

diff --git a/Modules/CMakePackageConfigHelpers.cmake 
b/Modules/CMakePackageConfigHelpers.cmake
index 318382e..712ced2 100644
--- a/Modules/CMakePackageConfigHelpers.cmake
+++ b/Modules/CMakePackageConfigHelpers.cmake
@@ -2,29 +2,35 @@
 # CMakePackageConfigHelpers
 # -------------------------
 #
-# CONFIGURE_PACKAGE_CONFIG_FILE(), WRITE_BASIC_PACKAGE_VERSION_FILE()
+# Helpers functions for creating config files that can be included by other
+# projects to find and use a package.
 #
+# Adds the :command:`configure_package_config_file()` and
+# :command:`write_basic_package_version_file()` commands.
 #
+# Generating a Package Configuration File
+# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 #
-# ::
+# .. command:: configure_package_config_file
 #
-#     CONFIGURE_PACKAGE_CONFIG_FILE(<input> <output> INSTALL_DESTINATION <path>
+#  Create a config file for a project::
+#
+#     configure_package_config_file(<input> <output> INSTALL_DESTINATION <path>
 #                                                    [PATH_VARS <var1> <var2> 
... <varN>]
 #                                                    [NO_SET_AND_CHECK_MACRO]
 #                                                    
[NO_CHECK_REQUIRED_COMPONENTS_MACRO])
 #
 #
+# ``configure_package_config_file()`` should be used instead of the plain
+# :command:`configure_file()` command when creating the ``<Name>Config.cmake``
+# or ``<Name>-config.cmake`` file for installing a project or library.  It 
helps
+# making the resulting package relocatable by avoiding hardcoded paths in the
+# installed ``Config.cmake`` file.
 #
-# CONFIGURE_PACKAGE_CONFIG_FILE() should be used instead of the plain
-# configure_file() command when creating the <Name>Config.cmake or
-# <Name>-config.cmake file for installing a project or library.  It
-# helps making the resulting package relocatable by avoiding hardcoded
-# paths in the installed Config.cmake file.
-#
-# In a FooConfig.cmake file there may be code like this to make the
-# install destinations know to the using project:
+# In a ``FooConfig.cmake`` file there may be code like this to make the install
+# destinations know to the using project:
 #
-# ::
+# .. code-block:: cmake
 #
 #    set(FOO_INCLUDE_DIR   "@CMAKE_INSTALL_FULL_INCLUDEDIR@" )
 #    set(FOO_DATA_DIR   "@CMAKE_INSTALL_PREFIX@/@RELATIVE_DATA_INSTALL_DIR@" )
@@ -32,121 +38,126 @@
 #    ...logic to determine installedPrefix from the own location...
 #    set(FOO_CONFIG_DIR  "${installedPrefix}/@CONFIG_INSTALL_DIR@" )
 #
-# All 4 options shown above are not sufficient, since the first 3
-# hardcode the absolute directory locations, and the 4th case works only
-# if the logic to determine the installedPrefix is correct, and if
-# CONFIG_INSTALL_DIR contains a relative path, which in general cannot
-# be guaranteed.  This has the effect that the resulting FooConfig.cmake
-# file would work poorly under Windows and OSX, where users are used to
-# choose the install location of a binary package at install time,
-# independent from how CMAKE_INSTALL_PREFIX was set at build/cmake time.
-#
-# Using CONFIGURE_PACKAGE_CONFIG_FILE() helps.  If used correctly, it
-# makes the resulting FooConfig.cmake file relocatable.  Usage:
+# All 4 options shown above are not sufficient, since the first 3 hardcode the
+# absolute directory locations, and the 4th case works only if the logic to
+# determine the ``installedPrefix`` is correct, and if ``CONFIG_INSTALL_DIR``
+# contains a relative path, which in general cannot be guaranteed.  This has 
the
+# effect that the resulting ``FooConfig.cmake`` file would work poorly under
+# Windows and OSX, where users are used to choose the install location of a
+# binary package at install time, independent from how
+# :variable:`CMAKE_INSTALL_PREFIX` was set at build/cmake time.
 #
-# ::
+# Using ``configure_package_config_file`` helps.  If used correctly, it makes
+# the resulting ``FooConfig.cmake`` file relocatable.  Usage:
 #
-#    1. write a FooConfig.cmake.in file as you are used to
-#    2. insert a line containing only the string "@PACKAGE_INIT@"
-#    3. instead of set(FOO_DIR "@SOME_INSTALL_DIR@"), use set(FOO_DIR 
"@PACKAGE_SOME_INSTALL_DIR@")
-#       (this must be after the @PACKAGE_INIT@ line)
-#    4. instead of using the normal configure_file(), use 
CONFIGURE_PACKAGE_CONFIG_FILE()
+#    1. write a ``FooConfig.cmake.in`` file as you are used to
+#    2. insert a line containing only the string ``@PACKAGE_INIT@``
+#    3. instead of ``set(FOO_DIR "@SOME_INSTALL_DIR@")``, use
+#       ``set(FOO_DIR "@PACKAGE_SOME_INSTALL_DIR@")`` (this must be after the
+#       ``@PACKAGE_INIT@`` line)
+#    4. instead of using the normal :command:`configure_file()`, use
+#       ``configure_package_config_file()``
 #
 #
 #
-# The <input> and <output> arguments are the input and output file, the
-# same way as in configure_file().
+# The ``<input>`` and ``<output>`` arguments are the input and output file, the
+# same way as in :command:`configure_file()`.
 #
-# The <path> given to INSTALL_DESTINATION must be the destination where
-# the FooConfig.cmake file will be installed to.  This can either be a
+# The ``<path>`` given to ``INSTALL_DESTINATION`` must be the destination where
+# the ``FooConfig.cmake`` file will be installed to.  This can either be a
 # relative or absolute path, both work.
 #
-# The variables <var1> to <varN> given as PATH_VARS are the variables
-# which contain install destinations.  For each of them the macro will
-# create a helper variable PACKAGE_<var...>.  These helper variables
-# must be used in the FooConfig.cmake.in file for setting the installed
-# location.  They are calculated by CONFIGURE_PACKAGE_CONFIG_FILE() so
-# that they are always relative to the installed location of the
-# package.  This works both for relative and also for absolute
-# locations.  For absolute locations it works only if the absolute
-# location is a subdirectory of CMAKE_INSTALL_PREFIX.
-#
-# By default configure_package_config_file() also generates two helper
-# macros, set_and_check() and check_required_components() into the
-# FooConfig.cmake file.
-#
-# set_and_check() should be used instead of the normal set() command for
-# setting directories and file locations.  Additionally to setting the
-# variable it also checks that the referenced file or directory actually
-# exists and fails with a FATAL_ERROR otherwise.  This makes sure that
-# the created FooConfig.cmake file does not contain wrong references.
-# When using the NO_SET_AND_CHECK_MACRO, this macro is not generated
-# into the FooConfig.cmake file.
-#
-# check_required_components(<package_name>) should be called at the end
-# of the FooConfig.cmake file if the package supports components.  This
-# macro checks whether all requested, non-optional components have been
-# found, and if this is not the case, sets the Foo_FOUND variable to
-# FALSE, so that the package is considered to be not found.  It does
-# that by testing the Foo_<Component>_FOUND variables for all requested
-# required components.  When using the NO_CHECK_REQUIRED_COMPONENTS
-# option, this macro is not generated into the FooConfig.cmake file.
+# The variables ``<var1>`` to ``<varN>`` given as ``PATH_VARS`` are the
+# variables which contain install destinations.  For each of them the macro 
will
+# create a helper variable ``PACKAGE_<var...>``.  These helper variables must 
be
+# used in the ``FooConfig.cmake.in`` file for setting the installed location.
+# They are calculated by ``configure_package_config_file`` so that they are
+# always relative to the installed location of the package.  This works both 
for
+# relative and also for absolute locations.  For absolute locations it works
+# only if the absolute location is a subdirectory of
+# :variable:`CMAKE_INSTALL_PREFIX`.
+#
+# By default ``configure_package_config_file`` also generates two helper 
macros,
+# ``set_and_check()`` and ``check_required_components()`` into the
+# ``FooConfig.cmake`` file.
+#
+# ``set_and_check()`` should be used instead of the normal ``set()`` command 
for
+# setting directories and file locations.  Additionally to setting the variable
+# it also checks that the referenced file or directory actually exists and 
failsù
+# with a ``FATAL_ERROR`` otherwise.  This makes sure that the created
+# ``FooConfig.cmake`` file does not contain wrong references.
+# When using the ``NO_SET_AND_CHECK_MACRO``, this macro is not generated
+# into the ``FooConfig.cmake`` file.
+#
+# ``check_required_components(<package_name>)`` should be called at the end of
+# the ``FooConfig.cmake`` file if the package supports components.  This macro
+# checks whether all requested, non-optional components have been found, and if
+# this is not the case, sets the ``Foo_FOUND`` variable to ``FALSE``, so that
+# the package is considered to be not found.  It does that by testing the
+# ``Foo_<Component>_FOUND`` variables for all requested required components.
+# When using the ``NO_CHECK_REQUIRED_COMPONENTS_MACRO`` option, this macro is
+# not generated into the ``FooConfig.cmake`` file.
 #
 # For an example see below the documentation for
-# WRITE_BASIC_PACKAGE_VERSION_FILE().
-#
-#
-#
-# ::
-#
-#   WRITE_BASIC_PACKAGE_VERSION_FILE( filename [VERSION major.minor.patch] 
COMPATIBILITY (AnyNewerVersion|SameMajorVersion|ExactVersion) )
-#
-#
-#
-# Writes a file for use as <package>ConfigVersion.cmake file to
-# <filename>.  See the documentation of find_package() for details on
-# this.
-#
-# ::
-#
-#     filename is the output filename, it should be in the build tree.
-#     major.minor.patch is the version number of the project to be installed
-#
-# If no ``VERSION`` is given, the :variable:`PROJECT_VERSION` variable
-# is used.  If this hasn't been set, it errors out.
-#
-# The COMPATIBILITY mode AnyNewerVersion means that the installed
-# package version will be considered compatible if it is newer or
-# exactly the same as the requested version.  This mode should be used
-# for packages which are fully backward compatible, also across major
-# versions.  If SameMajorVersion is used instead, then the behaviour
-# differs from AnyNewerVersion in that the major version number must be
-# the same as requested, e.g.  version 2.0 will not be considered
-# compatible if 1.0 is requested.  This mode should be used for packages
-# which guarantee backward compatibility within the same major version.
-# If ExactVersion is used, then the package is only considered
-# compatible if the requested version matches exactly its own version
-# number (not considering the tweak version).  For example, version
-# 1.2.3 of a package is only considered compatible to requested version
-# 1.2.3.  This mode is for packages without compatibility guarantees.
-# If your project has more elaborated version matching rules, you will
-# need to write your own custom ConfigVersion.cmake file instead of
-# using this macro.
-#
-# Internally, this macro executes configure_file() to create the
-# resulting version file.  Depending on the COMPATIBLITY, either the
-# file BasicConfigVersion-SameMajorVersion.cmake.in or
-# BasicConfigVersion-AnyNewerVersion.cmake.in is used.  Please note that
+# :command:`write_basic_package_version_file()`.
+#
+# Generating a Package Version File
+# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+#
+# .. command:: write_basic_package_version_file
+#
+#  Create a version file for a project::
+#
+#     write_basic_package_version_file(<filename>
+#                                      [VERSION <major.minor.patch>]
+#                                      COMPATIBILITY 
<AnyNewerVersion|SameMajorVersion|ExactVersion> )
+#
+#
+# Writes a file for use as ``<package>ConfigVersion.cmake`` file to
+# ``<filename>``.  See the documentation of :command:`find_package()` for
+# details on this.
+#
+# ``<filename>`` is the output filename, it should be in the build tree.
+# ``<major.minor.patch>`` is the version number of the project to be installed.
+#
+# If no ``VERSION`` is given, the :variable:`PROJECT_VERSION` variable is used.
+# If this hasn't been set, it errors out.
+#
+# The ``COMPATIBILITY`` mode ``AnyNewerVersion`` means that the installed
+# package version will be considered compatible if it is newer or exactly the
+# same as the requested version.  This mode should be used for packages which
+# are fully backward compatible, also across major versions.
+# If ``SameMajorVersion`` is used instead, then the behaviour differs from
+# ``AnyNewerVersion`` in that the major version number must be the same as
+# requested, e.g.  version 2.0 will not be considered compatible if 1.0 is
+# requested.  This mode should be used for packages which guarantee backward
+# compatibility within the same major version.
+# If ``ExactVersion`` is used, then the package is only considered compatible 
if
+# the requested version matches exactly its own version number (not considering
+# the tweak version).  For example, version 1.2.3 of a package is only
+# considered compatible to requested version 1.2.3.  This mode is for packages
+# without compatibility guarantees.
+# If your project has more elaborated version matching rules, you will need to
+# write your own custom ``ConfigVersion.cmake`` file instead of using this
+# macro.
+#
+# Internally, this macro executes :command:`configure_file()` to create the
+# resulting version file.  Depending on the ``COMPATIBLITY``, either the file
+# ``BasicConfigVersion-SameMajorVersion.cmake.in`` or
+# ``BasicConfigVersion-AnyNewerVersion.cmake.in`` is used.  Please note that
 # these two files are internal to CMake and you should not call
-# configure_file() on them yourself, but they can be used as starting
-# point to create more sophisticted custom ConfigVersion.cmake files.
+# :command:`configure_file()` on them yourself, but they can be used as 
starting
+# point to create more sophisticted custom ``ConfigVersion.cmake`` files.
 #
+# Example Generating Package Files
+# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 #
+# Example using both :command:`configure_package_config_file` and
+# ``write_basic_package_version_file()``:
 #
-# Example using both configure_package_config_file() and
-# write_basic_package_version_file(): CMakeLists.txt:
+# ``CMakeLists.txt``:
 #
-# ::
+# .. code-block:: cmake
 #
 #    set(INCLUDE_INSTALL_DIR include/ ... CACHE )
 #    set(LIB_INSTALL_DIR lib/ ... CACHE )
@@ -162,11 +173,9 @@
 #    install(FILES ${CMAKE_CURRENT_BINARY_DIR}/FooConfig.cmake 
${CMAKE_CURRENT_BINARY_DIR}/FooConfigVersion.cmake
 #            DESTINATION ${LIB_INSTALL_DIR}/Foo/cmake )
 #
+# ``FooConfig.cmake.in``:
 #
-#
-# With a FooConfig.cmake.in:
-#
-# ::
+# .. code-block:: cmake
 #
 #    set(FOO_VERSION x.y.z)
 #    ...
@@ -175,10 +184,6 @@
 #    set_and_check(FOO_INCLUDE_DIR "@PACKAGE_INCLUDE_INSTALL_DIR@")
 #    set_and_check(FOO_SYSCONFIG_DIR "@PACKAGE_SYSCONFIG_INSTALL_DIR@")
 #
-#
-#
-# ::
-#
 #    check_required_components(Foo)
 
 

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=64eca30dc4d584fb6acf8f6486c016eed50eb7ae
commit 64eca30dc4d584fb6acf8f6486c016eed50eb7ae
Author:     Daniele E. Domenichelli <daniele.domeniche...@iit.it>
AuthorDate: Tue Jul 15 18:47:05 2014 +0200
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Mon Aug 4 10:07:16 2014 -0400

    CMakePackageConfigHelpers: Remove unused variable

diff --git a/Modules/CMakePackageConfigHelpers.cmake 
b/Modules/CMakePackageConfigHelpers.cmake
index 473bbe5..318382e 100644
--- a/Modules/CMakePackageConfigHelpers.cmake
+++ b/Modules/CMakePackageConfigHelpers.cmake
@@ -203,8 +203,6 @@ macro(WRITE_BASIC_PACKAGE_VERSION_FILE)
   write_basic_config_version_file(${ARGN})
 endmacro()
 
-set(cfpch_dir ${CMAKE_CURRENT_LIST_DIR})
-
 function(CONFIGURE_PACKAGE_CONFIG_FILE _inputFile _outputFile)
   set(options NO_SET_AND_CHECK_MACRO NO_CHECK_REQUIRED_COMPONENTS_MACRO)
   set(oneValueArgs INSTALL_DESTINATION )

-----------------------------------------------------------------------

Summary of changes:
 Modules/CMakePackageConfigHelpers.cmake |  288 ++++++++++++++++---------------
 Tests/FindPackageTest/CMakeLists.txt    |   38 ++++
 2 files changed, 190 insertions(+), 136 deletions(-)


hooks/post-receive
diff --git a/Modules/CMakePackageConfigHelpers.cmake 
b/Modules/CMakePackageConfigHelpers.cmake
index 712ced2..6534583 100644
--- a/Modules/CMakePackageConfigHelpers.cmake
+++ b/Modules/CMakePackageConfigHelpers.cmake
@@ -18,7 +18,8 @@
 #     configure_package_config_file(<input> <output> INSTALL_DESTINATION <path>
 #                                                    [PATH_VARS <var1> <var2> 
... <varN>]
 #                                                    [NO_SET_AND_CHECK_MACRO]
-#                                                    
[NO_CHECK_REQUIRED_COMPONENTS_MACRO])
+#                                                    
[NO_CHECK_REQUIRED_COMPONENTS_MACRO]
+#                                                    [INSTALL_PREFIX <path>])
 #
 #
 # ``configure_package_config_file()`` should be used instead of the plain
@@ -64,8 +65,8 @@
 # same way as in :command:`configure_file()`.
 #
 # The ``<path>`` given to ``INSTALL_DESTINATION`` must be the destination where
 # the ``FooConfig.cmake`` file will be installed to.  This can either be a
 # relative or absolute path, both work.
 #
 # The variables ``<var1>`` to ``<varN>`` given as ``PATH_VARS`` are the
 # variables which contain install destinations.  For each of them the macro 
will
@@ -74,8 +75,14 @@
 # They are calculated by ``configure_package_config_file`` so that they are
 # always relative to the installed location of the package.  This works both 
for
 # relative and also for absolute locations.  For absolute locations it works
-# only if the absolute location is a subdirectory of
-# :variable:`CMAKE_INSTALL_PREFIX`.
+# only if the absolute location is a subdirectory of ``INSTALL_PREFIX``.
+#
+# If the ``INSTALL_PREFIX`` argument is passed, this is used as base path to
+# calculate all the relative paths.  If this argument is not passed, the
+# :variable:`CMAKE_INSTALL_PREFIX` variable will be used instead.  The default
+# value is good when generating a FooConfig.cmake file to use your package from
+# the install tree.  When generating a FooConfig.cmake file to use your package
+# from the build tree this option should be used.
 #
 # By default ``configure_package_config_file`` also generates two helper 
macros,
 # ``set_and_check()`` and ``check_required_components()`` into the
@@ -210,7 +217,7 @@ endmacro()
 
 function(CONFIGURE_PACKAGE_CONFIG_FILE _inputFile _outputFile)
   set(options NO_SET_AND_CHECK_MACRO NO_CHECK_REQUIRED_COMPONENTS_MACRO)
-  set(oneValueArgs INSTALL_DESTINATION )
+  set(oneValueArgs INSTALL_DESTINATION INSTALL_PREFIX)
   set(multiValueArgs PATH_VARS )
 
   cmake_parse_arguments(CCF "${options}" "${oneValueArgs}" "${multiValueArgs}" 
 ${ARGN})
@@ -223,20 +230,26 @@ function(CONFIGURE_PACKAGE_CONFIG_FILE _inputFile 
_outputFile)
     message(FATAL_ERROR "No INSTALL_DESTINATION given to 
CONFIGURE_PACKAGE_CONFIG_FILE()")
   endif()
 
+  if(DEFINED CCF_INSTALL_PREFIX)
+    set(installPrefix "${CCF_INSTALL_PREFIX}")
+  else()
+    set(installPrefix "${CMAKE_INSTALL_PREFIX}")
+  endif()
+
   if(IS_ABSOLUTE "${CCF_INSTALL_DESTINATION}")
     set(absInstallDir "${CCF_INSTALL_DESTINATION}")
   else()
-    set(absInstallDir "${CMAKE_INSTALL_PREFIX}/${CCF_INSTALL_DESTINATION}")
+    set(absInstallDir "${installPrefix}/${CCF_INSTALL_DESTINATION}")
   endif()
 
-  file(RELATIVE_PATH PACKAGE_RELATIVE_PATH "${absInstallDir}" 
"${CMAKE_INSTALL_PREFIX}" )
+  file(RELATIVE_PATH PACKAGE_RELATIVE_PATH "${absInstallDir}" 
"${installPrefix}" )
 
   foreach(var ${CCF_PATH_VARS})
     if(NOT DEFINED ${var})
       message(FATAL_ERROR "Variable ${var} does not exist")
     else()
       if(IS_ABSOLUTE "${${var}}")
-        string(REPLACE "${CMAKE_INSTALL_PREFIX}" "\${PACKAGE_PREFIX_DIR}"
+        string(REPLACE "${installPrefix}" "\${PACKAGE_PREFIX_DIR}"
                         PACKAGE_${var} "${${var}}")
       else()
         set(PACKAGE_${var} "\${PACKAGE_PREFIX_DIR}/${${var}}")
@@ -262,7 +275,7 @@ get_filename_component(PACKAGE_PREFIX_DIR 
\"\${CMAKE_CURRENT_LIST_DIR}/${PACKAGE
 get_filename_component(_realCurr \"\${CMAKE_CURRENT_LIST_DIR}\" REALPATH)
 get_filename_component(_realOrig \"${absInstallDir}\" REALPATH)
 if(_realCurr STREQUAL _realOrig)
-  set(PACKAGE_PREFIX_DIR \"${CMAKE_INSTALL_PREFIX}\")
+  set(PACKAGE_PREFIX_DIR \"${installPrefix}\")
 endif()
 unset(_realOrig)
 unset(_realCurr)
@@ -64,8 +65,8 @@
 #
 # The ``<path>`` given to ``INSTALL_DESTINATION`` must be the destination where
-# the ``FooConfig.cmake`` file will be installed to.  This can either be a
-# relative or absolute path, both work.
+# the ``FooConfig.cmake`` file will be installed to.  This path can either be
+# absolute, or relative to the ``INSTALL_PREFIX`` path.
 #
 # The variables ``<var1>`` to ``<varN>`` given as ``PATH_VARS`` are the

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=477babe0fc83f3cdfc58fc940c061f4d254810b2
commit 477babe0fc83f3cdfc58fc940c061f4d254810b2
Author:     Daniele E. Domenichelli <daniele.domeniche...@iit.it>
AuthorDate: Tue Jul 15 19:10:28 2014 +0200
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Mon Aug 4 10:07:17 2014 -0400

    CMakePackageConfigHelpers: restructure documentation and document commands

-- 
CMake
_______________________________________________
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits

Reply via email to